package com.uas.ps.entity;

import com.uas.ps.sync.core.annotation.Sync;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;
import java.util.Set;

/**
 * 物料
 *
 * @author sunyj
 * @since 2018/1/13 13:18
 */
@Sync
@Entity
@Table(name = "products", indexes = {
        @Index(name = "products_code_index", columnList = "pr_code"),
        @Index(name = "products_enuu_index", columnList = "pr_enuu"),
        @Index(name = "products_code_enuu_index", columnList = "pr_code, pr_enuu", unique = true)})
public class Product implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "pr_id")
    private Long id;

    /**
     * 商品信息标题
     */
    @Column(name = "pr_title")
    private String title;

    /**
     * 产品编号
     */
    @Column(name = "pr_code")
    private String code;

    /**
     * 产品规格
     */
    @Column(name = "pr_spec", columnDefinition = "text")
    private String spec;

    /**
     * 单位
     */
    @Column(name = "pr_unit")
    private String unit;

    /**
     * 所属企业UU
     */
    @Column(name = "pr_enuu")
    private Long enUU;

    /**
     * 个人UU 上传人的UU
     */
    @Column(name = "pr_useruu")
    private Long userUU;

    /**
     * 最小包装量
     */
    @Column(name = "pr_minpack")
    private Double minPack;

    /**
     * 最小采购量
     */
    @Column(name = "pr_minorder")
    private Double minOrder;

    /**
     * 采购提前期
     */
    @Column(name = "pr_leadtime")
    private Double leadTime;

    /**
     * 备货提前期（天数）
     */
    @Column(name = "pr_ltinstock")
    private Double ltinstock;

    /**
     * ERP空闲库存
     */
    @Column(name = "pr_reserve")
    private Double reserve;

    /**
     * 价格
     */
    @Column(name = "pr_price")
    private Double price;

    /**
     * 品牌（ERP) 上传时的品牌
     */
    @Column(name = "pr_brand")
    private String brand;

    /**
     * 原厂型号(erp) 用户上传的型号
     */
    @Column(name = "pr_cmpcode", length = 800)
    private String cmpCode;

    /**
     * 买方ERP物料ID
     */
    @Column(name = "pr_sourceid")
    private Long sourceId;

    /**
     * 保存erp传入数据的时间
     */
    @Column(name = "pr_erpdate")
    private Date erpDate;

    /**
     * UUID 标准料号
     */
    @Column(name = "pr_cmpuuid")
    private String cmpUuid;

    /**
     * 应用来源<br>
     * 平台上传的为可以销售的
     */
    @Column(name = "pr_sourceapp")
    private String sourceApp;

    /**
     * 类目（平台）（中文）
     */
    @Column(name = "pr_kind")
    private String kind;

    /**
     * 类目（平台）（英文）
     */
    @Column(name = "pr_kinden")
    private String kindEn;

    /**
     * 类目的id
     */
    @Column(name = "pr_kindid")
    private Long kindId;

    /**
     * 品牌（平台）（中文）
     */
    @Column(name = "pr_pbrand")
    private String pBrand;

    /**
     * 品牌（平台）（英文）
     */
    @Column(name = "pr_pbranden")
    private String pBrandEn;

    /**
     * 品牌（平台）id
     */
    @Column(name = "pr_pbrandid")
    private Long pBrandId;

    /**
     * 品牌（平台）（uuid）
     */
    @Column(name = "pr_pbranduuid")
    private String pBrandUuid;

    /**
     * 型号（平台）
     */
    @Column(name = "pr_pcmpcode", length = 800)
    private String pCmpCode;

    /**
     * 是否可卖<br>
     * 1. 可以卖 <br>
     * 0. 不可
     */
    @Column(name = "pr_issale")
    private Short isSale;

    /**
     * 是否可买<br>
     * 1. 可以买<br>
     * 0. 不可
     */
    @Column(name = "pr_ispurchase")
    private Short isPurchase;

    /**
     * 公开展示<br>
     * <p>
     * 1. 是<br>
     * 0. 否
     */
    @Column(name = "pr_isshow")
    private Short isShow;

    /**
     * 公开销售 <br>
     * 1. 是<br>
     * 0. 否
     */
    @Column(name = "pr_ispubsale")
    private Short isPubsale;

    /**
     * 附件
     */
    @Column(name = "pr_attachment")
    private String attachment;

    /**
     * 是否是标准物料<br>
     * 1.YES<br>
     * 0.NO
     */
    @Column(name = "pr_standard")
    private Short standard;

    /**
     * 匹配状态（记录匹配状态，方便下次查看）
     */
    @Column(name = "pr_matchstatus")
    private Integer matchStatus;

    /**
     * 匹配数量（用作排序）
     */
    @Column(name = "pr_matchsize")
    private Integer matchSize;

    /**
     * 匹配结果
     */
    @OneToMany(mappedBy = "product", cascade = {CascadeType.REFRESH}, fetch = FetchType.EAGER)
    private Set<ProductMatchResult> matchResults;

    /**
     * 封装
     */
    @Column(name = "pr_encapsulation")
    private String encapsulation;

    /**
     * 包装：托盘、管装、卷带
     */
    @Column(name = "pr_packaging")
    private String packaging;

    /**
     * 图片
     */
    @Column(name = "pr_cmpimg")
    private String cmpImg;

    /**
     * 产品建立时间
     */
    @Column(name = "pr_create_time")
    private Date createTime;

    /**
     * 匹配为标准时的系统时间
     */
    @Column(name = "pr_tostandard")
    private Date toStandard;

    /**
     * 下载状态，平台更新ERP的数据后，将数据回传回ERP更新
     */
    @Column(name = "pr_downloadstatus")
    private Integer downloadStatus;

    /**
     * 产品生产日期
     */
    @Column(name = "pr_manufacturedate")
    private String manufactureDate;

    /**
     * 编码版本号
     */
    @Column(name = "pr_goodsnover")
    private String goodsNover;

    /**
     * 税收分类编码
     */
    @Column(name = "pr_goodstaxno")
    private String goodsTaxNo;

    /**
     * 是否享受优惠政策
     */
    @Column(name = "pr_taxpre")
    private String taxPre;

    /**
     * 享受优惠政策内容
     */
    @Column(name = "pr_taxprecon")
    private String taxPreCon;

    /**
     * 最长交期
     */
    @Column(name = "pr_maxdelivery")
    private Short maxDelivery;

    /**
     * 最短交期
     */
    @Column(name = "pr_mindelivery")
    private Short minDelivery;

    /**
     * 是否拆卖
     */
    @Column(name = "pr_isbreakup")
    private Boolean isBreakUp;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public Long getEnUU() {
        return enUU;
    }

    public void setEnUU(Long enUU) {
        this.enUU = enUU;
    }

    public Long getUserUU() {
        return userUU;
    }

    public void setUserUU(Long userUU) {
        this.userUU = userUU;
    }

    public Double getMinPack() {
        return minPack;
    }

    public void setMinPack(Double minPack) {
        this.minPack = minPack;
    }

    public Double getMinOrder() {
        return minOrder;
    }

    public void setMinOrder(Double minOrder) {
        this.minOrder = minOrder;
    }

    public Double getLeadTime() {
        return leadTime;
    }

    public void setLeadTime(Double leadTime) {
        this.leadTime = leadTime;
    }

    public Double getLtinstock() {
        return ltinstock;
    }

    public void setLtinstock(Double ltinstock) {
        this.ltinstock = ltinstock;
    }

    public Double getReserve() {
        return reserve;
    }

    public void setReserve(Double reserve) {
        this.reserve = reserve;
    }

    public Double getPrice() {
        return price;
    }

    public void setPrice(Double price) {
        this.price = price;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public String getCmpCode() {
        return cmpCode;
    }

    public void setCmpCode(String cmpCode) {
        this.cmpCode = cmpCode;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Date getErpDate() {
        return erpDate;
    }

    public void setErpDate(Date erpDate) {
        this.erpDate = erpDate;
    }

    public String getCmpUuid() {
        return cmpUuid;
    }

    public void setCmpUuid(String cmpUuid) {
        this.cmpUuid = cmpUuid;
    }

    public String getSourceApp() {
        return sourceApp;
    }

    public void setSourceApp(String sourceApp) {
        this.sourceApp = sourceApp;
    }

    public String getKind() {
        return kind;
    }

    public void setKind(String kind) {
        this.kind = kind;
    }

    public String getKindEn() {
        return kindEn;
    }

    public void setKindEn(String kindEn) {
        this.kindEn = kindEn;
    }

    public Long getKindId() {
        return kindId;
    }

    public void setKindId(Long kindId) {
        this.kindId = kindId;
    }

    public String getpBrand() {
        return pBrand;
    }

    public void setpBrand(String pBrand) {
        this.pBrand = pBrand;
    }

    public String getpBrandEn() {
        return pBrandEn;
    }

    public void setpBrandEn(String pBrandEn) {
        this.pBrandEn = pBrandEn;
    }

    public Long getpBrandId() {
        return pBrandId;
    }

    public void setpBrandId(Long pBrandId) {
        this.pBrandId = pBrandId;
    }

    public String getpBrandUuid() {
        return pBrandUuid;
    }

    public void setpBrandUuid(String pBrandUuid) {
        this.pBrandUuid = pBrandUuid;
    }

    public String getpCmpCode() {
        return pCmpCode;
    }

    public void setpCmpCode(String pCmpCode) {
        this.pCmpCode = pCmpCode;
    }

    public Short getIsSale() {
        return isSale;
    }

    public void setIsSale(Short isSale) {
        this.isSale = isSale;
    }

    public Short getIsPurchase() {
        return isPurchase;
    }

    public void setIsPurchase(Short isPurchase) {
        this.isPurchase = isPurchase;
    }

    public Short getIsShow() {
        return isShow;
    }

    public void setIsShow(Short isShow) {
        this.isShow = isShow;
    }

    public Short getIsPubsale() {
        return isPubsale;
    }

    public void setIsPubsale(Short isPubsale) {
        this.isPubsale = isPubsale;
    }

    public String getAttachment() {
        return attachment;
    }

    public void setAttachment(String attachment) {
        this.attachment = attachment;
    }

    public Short getStandard() {
        return standard;
    }

    public void setStandard(Short standard) {
        this.standard = standard;
    }

    public Integer getMatchStatus() {
        return matchStatus;
    }

    public void setMatchStatus(Integer matchStatus) {
        this.matchStatus = matchStatus;
    }

    public Integer getMatchSize() {
        return matchSize;
    }

    public void setMatchSize(Integer matchSize) {
        this.matchSize = matchSize;
    }

    public Set<ProductMatchResult> getMatchResults() {
        return matchResults;
    }

    public void setMatchResults(Set<ProductMatchResult> matchResults) {
        this.matchResults = matchResults;
    }

    public String getEncapsulation() {
        return encapsulation;
    }

    public void setEncapsulation(String encapsulation) {
        this.encapsulation = encapsulation;
    }

    public String getPackaging() {
        return packaging;
    }

    public void setPackaging(String packaging) {
        this.packaging = packaging;
    }

    public String getCmpImg() {
        return cmpImg;
    }

    public void setCmpImg(String cmpImg) {
        this.cmpImg = cmpImg;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getToStandard() {
        return toStandard;
    }

    public void setToStandard(Date toStandard) {
        this.toStandard = toStandard;
    }

    public Integer getDownloadStatus() {
        return downloadStatus;
    }

    public void setDownloadStatus(Integer downloadStatus) {
        this.downloadStatus = downloadStatus;
    }

    public String getManufactureDate() {
        return manufactureDate;
    }

    public void setManufactureDate(String manufactureDate) {
        this.manufactureDate = manufactureDate;
    }

    public String getGoodsNover() {
        return goodsNover;
    }

    public void setGoodsNover(String goodsNover) {
        this.goodsNover = goodsNover;
    }

    public String getGoodsTaxNo() {
        return goodsTaxNo;
    }

    public void setGoodsTaxNo(String goodsTaxNo) {
        this.goodsTaxNo = goodsTaxNo;
    }

    public String getTaxPre() {
        return taxPre;
    }

    public void setTaxPre(String taxPre) {
        this.taxPre = taxPre;
    }

    public String getTaxPreCon() {
        return taxPreCon;
    }

    public void setTaxPreCon(String taxPreCon) {
        this.taxPreCon = taxPreCon;
    }

    public Short getMaxDelivery() {
        return maxDelivery;
    }

    public void setMaxDelivery(Short maxDelivery) {
        this.maxDelivery = maxDelivery;
    }

    public Short getMinDelivery() {
        return minDelivery;
    }

    public void setMinDelivery(Short minDelivery) {
        this.minDelivery = minDelivery;
    }

    public Boolean getBreakUp() {
        return isBreakUp;
    }

    public void setBreakUp(Boolean breakUp) {
        isBreakUp = breakUp;
    }

    @Override
    public String toString() {
        return "Product{" +
                "id=" + id +
                ", title='" + title + '\'' +
                ", code='" + code + '\'' +
                ", spec='" + spec + '\'' +
                ", unit='" + unit + '\'' +
                ", enUU=" + enUU +
                ", userUU=" + userUU +
                ", minPack=" + minPack +
                ", minOrder=" + minOrder +
                ", leadTime=" + leadTime +
                ", ltinstock=" + ltinstock +
                ", reserve=" + reserve +
                ", price=" + price +
                ", brand='" + brand + '\'' +
                ", cmpCode='" + cmpCode + '\'' +
                ", sourceId=" + sourceId +
                ", erpDate=" + erpDate +
                ", cmpUuid='" + cmpUuid + '\'' +
                ", sourceApp='" + sourceApp + '\'' +
                ", kind='" + kind + '\'' +
                ", kindEn='" + kindEn + '\'' +
                ", kindId=" + kindId +
                ", pBrand='" + pBrand + '\'' +
                ", pBrandEn='" + pBrandEn + '\'' +
                ", pBrandId=" + pBrandId +
                ", pBrandUuid='" + pBrandUuid + '\'' +
                ", pCmpCode='" + pCmpCode + '\'' +
                ", isSale=" + isSale +
                ", isPurchase=" + isPurchase +
                ", isShow=" + isShow +
                ", isPubsale=" + isPubsale +
                ", attachment='" + attachment + '\'' +
                ", standard=" + standard +
                ", matchStatus=" + matchStatus +
                ", matchSize=" + matchSize +
                ", matchResults=" + matchResults +
                ", encapsulation='" + encapsulation + '\'' +
                ", packaging='" + packaging + '\'' +
                ", cmpImg='" + cmpImg + '\'' +
                ", createTime=" + createTime +
                ", toStandard=" + toStandard +
                ", downloadStatus=" + downloadStatus +
                ", manufactureDate=" + manufactureDate +
                ", goodsNover='" + goodsNover + '\'' +
                ", goodsTaxNo='" + goodsTaxNo + '\'' +
                ", taxPre='" + taxPre + '\'' +
                ", taxPreCon='" + taxPreCon + '\'' +
                ", maxDelivery=" + maxDelivery +
                ", minDelivery=" + minDelivery +
                ", isBreakUp=" + isBreakUp +
                '}';
    }
}
